@@ -1,3 +1,4 @@
+#include "config.h"
 #include "mold.h"
 
 #include <filesystem>
@@ -784,7 +785,8 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
     } else if (read_flag("Bno-symbolic")) {
       ctx.arg.Bsymbolic = BSYMBOLIC_NONE;
     } else if (read_arg("exclude-libs")) {
-      append(ctx.arg.exclude_libs, split_by_comma_or_colon(arg));
+      for (std::string_view lib : split_by_comma_or_colon(arg))
+        ctx.arg.exclude_libs.insert(lib);
     } else if (read_flag("q") || read_flag("emit-relocs")) {
       ctx.arg.emit_relocs = true;
       ctx.arg.discard_locals = false;
@@ -858,10 +860,8 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
     } else if (read_arg("sysroot")) {
       ctx.arg.sysroot = arg;
     } else if (read_arg("unique")) {
-      std::optional<Glob> pat = Glob::compile(arg);
-      if (!pat)
+      if (!ctx.arg.unique.add(arg, 1))
         Fatal(ctx) << "-unique: invalid glob pattern: " << arg;
-      ctx.arg.unique = std::move(*pat);
     } else if (read_arg("unresolved-symbols")) {
       if (arg == "report-all" || arg == "ignore-in-shared-libs")
         report_undefined = true;
@@ -981,11 +981,11 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
       ctx.arg.execute_only = true;
     } else if (read_arg("compress-debug-sections")) {
       if (arg == "zlib" || arg == "zlib-gabi")
-        ctx.arg.compress_debug_sections = COMPRESS_ZLIB;
+        ctx.arg.compress_debug_sections = ELFCOMPRESS_ZLIB;
       else if (arg == "zstd")
-        ctx.arg.compress_debug_sections = COMPRESS_ZSTD;
+        ctx.arg.compress_debug_sections = ELFCOMPRESS_ZSTD;
       else if (arg == "none")
-        ctx.arg.compress_debug_sections = COMPRESS_NONE;
+        ctx.arg.compress_debug_sections = ELFCOMPRESS_NONE;
       else
         Fatal(ctx) << "invalid --compress-debug-sections argument: " << arg;
     } else if (read_arg("wrap")) {
@@ -1305,6 +1305,7 @@ std::vector<std::string> parse_nonpositional_args(Context<E> &ctx) {
           << " binary file into an object file, use `objcopy -I binary -O"
           << " default <input-file> <output-file.o>` instead.";
       Fatal(ctx) << "unknown command line option: -b " << arg;
+    } else if (read_arg("fuse-ld")) {
     } else if (read_arg("auxiliary") || read_arg("f")) {
       ctx.arg.auxiliary.push_back(arg);
     } else if (read_arg("filter") || read_arg("F")) {
