@@ -1,11 +1,9 @@
 #include "mold.h"
-#include "../lib/archive-file.h"
 
 #include <cstring>
 #include <functional>
 #include <sys/stat.h>
 #include <sys/types.h>
-#include <tbb/global_control.h>
 #include <unordered_set>
 
 #ifdef _WIN32
@@ -249,7 +247,7 @@ static void read_input_files(Context<E> &ctx, std::span<std::string> args) {
     }
   }
 
-  if (ctx.objs.empty())
+  if (ctx.objs.empty() && ctx.dsos.empty())
     Fatal(ctx) << "no input files";
 
   tg.wait();
@@ -299,8 +297,8 @@ int mold_main(int argc, char **argv) {
 
   acquire_global_lock();
 
-  tbb::global_control tbb_cont(tbb::global_control::max_allowed_parallelism,
-                               ctx.arg.thread_count);
+  ctx.global_limit.emplace(tbb::global_control::max_allowed_parallelism,
+                           ctx.arg.thread_count);
 
   // Handle --wrap options if any.
   for (std::string_view name : ctx.arg.wrap)
@@ -577,8 +575,8 @@ int mold_main(int argc, char **argv) {
   // GOT or PLT addresses have a correct final value.
 
   // If --compress-debug-sections is given, compress .debug_* sections
-  // using zlib.
-  if (ctx.arg.compress_debug_sections != COMPRESS_NONE) {
+  // using zlib or zstd.
+  if (ctx.arg.compress_debug_sections != ELFCOMPRESS_NONE) {
     compress_debug_sections(ctx);
     filesize = set_osec_offsets(ctx);
   }
